@@ -276,6 +276,14 @@ class R3sponse(object):
 			if not isinstance(dictionary, dict):
 				raise TypeError("You can only self assign with a dictionary as parameter.")
 			for key,value in dictionary.items():
+				if value in ["False", "false"]: value = False
+				elif value in ["True", "true"]: value = True
+				elif value in ["None", "none", "null", "nan"]: value = None
+				else:
+					try: 
+						int(value)
+						value = int(value)
+					except: a=1
 				self[key] = value
 		# clean default values.
 		def clean(self):
